OSDN Git Service

Per some comments from Lars Kellogg-Stedman <lars@larsshack.org>,
authorEric Andersen <andersen@codepoet.org>
Mon, 7 May 2001 17:48:28 +0000 (17:48 -0000)
committerEric Andersen <andersen@codepoet.org>
Mon, 7 May 2001 17:48:28 +0000 (17:48 -0000)
make xreadlink() return NULL on failure, and make sure everyone
uses the interface correctly.
 -Erik

applets/busybox.c
archival/tar.c
busybox.c
libbb/xreadlink.c
miscutils/readlink.c
readlink.c
tar.c

index badd53d..41b6069 100644 (file)
@@ -37,10 +37,7 @@ typedef int (*__link_f)(const char *, const char *);
  */
 static char *busybox_fullpath()
 {
-       char proc[256];
-
-       sprintf(proc, "/proc/%d/exe", getpid());
-       return xreadlink(proc);
+       return xreadlink("/proc/self/exe");
 }
 
 /* create (sym)links for each applet */
index eb085c7..135bfd1 100644 (file)
@@ -922,6 +922,8 @@ writeTarHeader(struct TarBallInfo *tbInfo, const char *header_name,
                strncpy(header.linkname, tbInfo->hlInfo->name, sizeof(header.linkname));
        } else if (S_ISLNK(statbuf->st_mode)) {
                char *lpath = xreadlink(real_name);
+               if (!lpath) /* Already printed err msg inside xreadlink() */
+                       return ( FALSE);
                header.typeflag  = SYMTYPE;
                strncpy(header.linkname, lpath, sizeof(header.linkname)); 
                free(lpath);
index badd53d..41b6069 100644 (file)
diff --git a/tar.c b/tar.c
index eb085c7..135bfd1 100644 (file)
--- a/tar.c
+++ b/tar.c
@@ -922,6 +922,8 @@ writeTarHeader(struct TarBallInfo *tbInfo, const char *header_name,
                strncpy(header.linkname, tbInfo->hlInfo->name, sizeof(header.linkname));
        } else if (S_ISLNK(statbuf->st_mode)) {
                char *lpath = xreadlink(real_name);
+               if (!lpath) /* Already printed err msg inside xreadlink() */
+                       return ( FALSE);
                header.typeflag  = SYMTYPE;
                strncpy(header.linkname, lpath, sizeof(header.linkname)); 
                free(lpath);
--- a/busybox.c
+++ b/busybox.c
@@ -37,10 +37,7 @@ typedef int (*__link_f)(const char *, const char *);
  */
 static char *busybox_fullpath()
 {
-       char proc[256];
-
-       sprintf(proc, "/proc/%d/exe", getpid());
-       return xreadlink(proc);
+       return xreadlink("/proc/self/exe");
 }
 
 /* create (sym)links for each applet */
index 66f63b8..932e487 100644 (file)
@@ -1,5 +1,6 @@
 /*
*  xreadlink.c - safe implementation of readlink
  */
 
 #include <stdio.h>
@@ -22,8 +23,10 @@ extern char *xreadlink(const char *path)
        do {
                buf = xrealloc(buf, bufsize += GROWBY);
                readsize = readlink(path, buf, bufsize); /* 1st try */
-               if (readsize == -1)
-                       perror_msg("%s:%s", applet_name, path);
+               if (readsize == -1) {
+                   perror_msg("%s:%s", applet_name, path);
+                   return NULL;
+               }
        }           
        while (bufsize < readsize + 1);
 
index 2266495..c46ebd1 100644 (file)
@@ -37,6 +37,8 @@ int readlink_main(int argc, char **argv)
                show_usage();
 
        buf = xreadlink(argv[1]);
+       if (!buf)
+               return EXIT_FAILURE;
        puts(buf);
 #ifdef BB_FEATURE_CLEAN_UP
        free(buf);
index 2266495..c46ebd1 100644 (file)
@@ -37,6 +37,8 @@ int readlink_main(int argc, char **argv)
                show_usage();
 
        buf = xreadlink(argv[1]);
+       if (!buf)
+               return EXIT_FAILURE;
        puts(buf);
 #ifdef BB_FEATURE_CLEAN_UP
        free(buf);
@@ -1,5 +1,6 @@
 /*
- *  xreadlink.c - safe implementation of readlink
+ *  xreadlink.c - safe implementation of readlink.
+ *  Returns a NULL on failure...
  */
 